import { game, Sprite, toDegree, UITransform, _decorator } from "cc";

const { requireComponent, ccclass } = _decorator;

function distanceXY(ax: number, ay: number, bx: number, by: number): number {
    const dx = bx - ax;
    const dy = by - ay;

    return Math.sqrt(dx * dx + dy * dy);
};

@ccclass("TestTile")
@requireComponent(UITransform)
export class TestTileComponent extends Sprite {
    private _trans: UITransform;

    onLoad(): void {
        this._trans = this.getComponent(UITransform);

        this.type = Sprite.Type.TILED;
        this.sizeMode = Sprite.SizeMode.CUSTOM;
        this._trans.anchorPoint.set(0, .5);
    }

    castTo(worldX: number, worldY: number): void {
        const x = this.node.worldPosition.x;
        const y = this.node.worldPosition.y;
        const w = worldX - x;
        const h = worldY - y;

        const len = distanceXY(x, y, worldX, worldY);
        const angle = Math.atan2(h, w);
        
        this._trans.contentSize.set(len, this._trans.contentSize.height);
        this.node.angle = toDegree(angle);
    }

    update(delta: number): void {
        const p = this.node.worldPosition;
        this.castTo(p.x + Math.cos(game.totalTime * .001) * Math.random() * 200 + 100, p.y + Math.sin(game.totalTime * .001) * 300);
    }
}
